:orphan:


SubModule: ``activate_virtualenv``
==================================

.. automodule:: soma.activate_virtualenv
    :members:


SubModule: ``application``
==========================

.. automodule:: soma.application
    :members:


SubModule: ``archive``
======================

.. automodule:: soma.archive
    :members:


SubModule: ``bufferandfile``
============================

.. automodule:: soma.bufferandfile
    :members:


SubModule: ``config``
=====================

.. automodule:: soma.config
    :members:


.. _controller:

SubModule: ``controller``: objects with typed fields
====================================================

Classes
-------
* :class:`soma.controller.controller.Controller`
* :class:`soma.controller.controller.Event`
* :class:`soma.controller.controller.AttributeValueEvent`
* :class:`soma.controller.controller.OpenKeyController`

API
---

.. automodule:: soma.controller
    :members:

.. automodule:: soma.controller.controller
    :members:

.. automodule:: soma.controller.field
    :members:


SubModule: ``crypt``
====================

.. automodule:: soma.crypt
    :members:


SubModule: ``debug``
====================

.. automodule:: soma.debug
    :members:


SubModule: ``factory``
======================

.. automodule:: soma.factory
    :members:


SubModule: ``fom``: File Organization Model
===========================================

.. automodule:: soma.fom
    :members:


SubModule: ``global_naming``
============================

.. automodule:: soma.global_naming
    :members:


SubModule: ``html``
===================

.. automodule:: soma.html
    :members:


SubModule: ``importer``
=======================

.. automodule:: soma.importer
    :members:


SubModule: ``info``
===================

.. automodule:: soma.info
    :members:


SubModule: ``logging``
======================

.. automodule:: soma.logging
    :members:


SubModule: ``minf``
===================

.. automodule:: soma.minf.api
    :members:


SubModule: ``mpfork``
=====================

.. automodule:: soma.mpfork
    :members:


SubModule: ``notification``
===========================

.. automodule:: soma.notification
    :members:


SubModule: ``path``
===================

.. automodule:: soma.path
    :members:


SubModule: ``qimage2ndarray``
=============================

.. automodule:: soma.qimage2ndarray
    :members:

SubModule: ``qt_gui``
=====================

.. automodule:: soma.qt_gui
    :members:

SubModule: ``qt_gui.controller``
================================

Classes
-------

* :class:`soma.qt_gui.controller.controller.ControllerWidget`

API
---

.. automodule:: soma.qt_gui.controller
    :members:

SubModule: ``qt_gui.io``
========================

.. automodule:: soma.qt_gui.io
    :members:

SubModule: ``qt_gui.qt_backend``
================================

.. automodule:: soma.qt_gui.qt_backend
    :members:

SubModule: ``qt_gui.qtThread``
==============================

.. automodule:: soma.qt_gui.qtThread
    :members:

SubModule: ``qt_gui.rangeSlider``
=================================

.. automodule:: soma.qt_gui.rangeSlider
    :members:

SubModule: ``qt_gui.timered_widgets``
=====================================

.. automodule:: soma.qt_gui.timered_widgets
    :members:

SubModule: ``safemkdir``
========================

.. automodule:: soma.safemkdir
    :members:


SubModule: ``singleton``
========================

.. automodule:: soma.singleton
    :members:


SubModule: ``somatime``
=======================

.. automodule:: soma.somatime
    :members:


SubModule: ``sorted_dictionary``
================================

.. automodule:: soma.sorted_dictionary
    :members:


SubModule: ``sqlite_tools``
===========================

.. automodule:: soma.sqlite_tools
    :members:


SubModule: ``stringtools``
==========================

.. automodule:: soma.stringtools
    :members:


SubModule: ``thread_calls``
===========================

.. automodule:: soma.thread_calls
    :members:


SubModule: ``translation``
==========================

.. automodule:: soma.translation
    :members:


SubModule: ``undefined``
========================

.. automodule:: soma.undefined
    :members:


SubModule: ``utils``
====================

.. automodule:: soma.utils
    :members:

SubModule: ``utils.find_library``
---------------------------------
.. automodule:: soma.utils.find_library
    :members:

SubModule: ``utils.functiontools``
----------------------------------

.. automodule:: soma.utils.functiontools
    :members:

SubModule: ``utils.loader``
---------------------------
.. automodule:: soma.utils.loader
    :members:

SubModule: ``utils.weak_proxy``
-------------------------------
.. automodule:: soma.utils.weak_proxy
    :members:


SubModule: ``uuid``
===================

.. automodule:: soma.uuid
    :members:
